@@ -1,7 +1,7 @@
 package Module::DataPack;
 
-our $DATE = '2015-06-18'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-07-03'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -96,13 +96,13 @@ sub datapack_modules {
     my %module_srcs; # key: mod_pm
     if ($args{module_srcs}) {
         for my $mod (keys %{ $args{module_srcs} }) {
-            my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm";
+            my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm" unless $mod_pm =~ /\.pm\z/;
             $module_srcs{$mod_pm} = $args{module_srcs}{$mod};
         }
     } else {
         require Module::Path::More;
         for my $mod (@{ $args{module_names} }) {
-            my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm";
+            my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm" unless $mod_pm =~ /\.pm\z/;
             next if $module_srcs{$mod_pm};
             my $path = Module::Path::More::module_path(
                 module => $mod, find_pmc=>0);
@@ -242,7 +242,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.04 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-06-18.
+This document describes version 0.05 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-07-03.
 
 =head1 SEE ALSO
 
